{% load i18n %}
{% load common competition %}
<td class="datetime">{{ match.datetime|date }} {{ match.datetime|time }}</td>
<td class="team {{ opponent.club.slug|cssify }}">
	<span class="versus">vs </span>
	{% if opponent.club %}
		{% url application.name|add:":club" competition=competition.slug season=season.slug club=opponent.club.slug as url1 %}
		{% url application.name|add:":club" season=season.slug club=opponent.club.slug as url2 %}
		{% url application.name|add:":club" club=opponent.club.slug as url3 %}
		<a href="{{ url1|default:url2|default:url3 }}">{% trans opponent.title %}</a>
	{% elif opponent.slug %}
		{% url application.name|add:":team" competition=competition.slug season=season.slug division=opponent.division.slug team=opponent.slug as url1 %}
		{% url application.name|add:":team" season=season.slug division=opponent.division.slug team=opponent.slug as url2 %}
		{% url application.name|add:":team" division=opponent.division.slug team=opponent.slug as url3 %}
		<a href="{{ url1|default:url2|default:url3 }}">{% trans opponent.title %}</a>
	{% else %}
		{% trans opponent.title %}
	{% endif %}
</td>
<td>{% score match team %}</td>
