{% extends "touchtechnology/news/archive/base.html" %}
{% load i18n tz %}

{% block page_title %}{{ block.super }}: {% trans "Archive" %}{% endblock %}

{% block archive_info %}
	<h2>{% trans "Archive" %}</h2>

	<ul>
		{% for year in date_list %}
			<li><a href="{% url application.name|add:":year" year=year|date:"Y" %}">{{ year|date:"Y" }}</a></li>
		{% endfor %}
	</ul>

	<h3>{% trans "Latest" %}</h3>

	<ul>
		{% for article in latest %}
			<li><a href="{% timezone "UTC" %}{% url application.name|add:":article" year=article.published|date:"Y" month=article.published|date:"b" day=article.published|date:"j" slug=article.slug %}{% endtimezone %}">{{ article.headline }}</a></li>
		{% endfor %}
	</ul>
{% endblock %}
